==> qtox-1.3.0.tar.gz: qTox-1.3.0/README.md <==
qTox
======

 [**User Manual**](/doc/user_manual_en.md) **⦁** [**Compile**](/INSTALL.md) **⦁** [**Contribute**](https://github.com/tux3/qTox/wiki#contributing) **⦁** [**Report bugs**](https://github.com/tux3/qTox/wiki/Writing-Useful-Bug-Reports) **⦁** [**Translate**](https://github.com/tux3/qTox/wiki/Translating) **⦁** [**Jenkins builds**](https://build.tox.chat/) **⦁** [**Keyboard shortcuts**](https://github.com/tux3/qTox/wiki/Keyboard-shortcuts) **⦁** [**Mailing list**](https://lists.tox.chat) **⦁** **IRC Channel:** [#qtox@freenode](https://webchat.freenode.net/?channels=qtox)

**qTox is a powerful Tox client that follows the Tox design guidelines while running on all major platforms.**

----

* **Windows**:
  - [**64 bit installer**](https://build.tox.chat/view/qtox/job/qTox_pkg_windows_x86-64_stable_release/lastSuccessfulBuild/artifact/setup-qtox.exe)
  - [**32 bit installer**](https://build.tox.chat/view/qtox/job/qTox_pkg_windows_x86_stable_release/lastSuccessfulBuild/artifact/setup-qtox.exe)
  - [**64 bit portable**](https://build.tox.chat/job/qTox_build_windows_x86-64_release/lastSuccessfulBuild/artifact/qTox_build_windows_x86-64_release.zip)
  - [**32 bit portable**](https://build.tox.chat/job/qTox_build_windows_x86_release/lastSuccessfulBuild/artifact/qTox_build_windows_x86_release.zip)
* **Linux**:
  - [**64 bit download**](https://build.tox.chat/view/Clients/job/qTox_build_linux_x86-64_release/lastSuccessfulBuild/artifact/qTox_build_linux_x86-64_release.tar.xz)
  - [**32 bit download**](https://build.tox.chat/view/Clients/job/qTox_build_linux_x86_release/lastSuccessfulBuild/artifact/qTox_build_linux_x86_release.tar.xz)
  - [**Armhf download**](https://build.tox.chat/job/qTox-qt5.4.2_build_linux_armhf_release/lastSuccessfulBuild/artifact/qTox-qt5.4.2_build_linux_armhf_release.tar.xz)
  - [**packages**](/INSTALL.md#simple-install)
  - [**Gentoo overlay**](https://github.com/zetok/gentoo-overlay-tox)
* **Mac**:
  - [**Experimental download**](https://github.com/RowenStipe/qTox-OSX/releases)
* **FreeBSD**:
  - [**Port**](/INSTALL.md#freebsd-easy)
<br/>

Builds other than installer/packages don't receive updates automatically, so make sure you get back to this site and regularly download the latest version of qTox.


#### Screenshots
Note: The screenshots may not always be up to date, but they should give a good idea of the general look and features.


![Screenshot 01](https://i.imgur.com/hwGmDeK.png)
![Screenshot 02](https://i.imgur.com/tmX8z9s.png)


#### Features

- One to one chat with friends
- Group chats
- File transfers, with previewing of images
- Audio calls, including group calls
- Video calls
- Tox DNS and Tox URI support
- Translations in various languages
- Avatars
- Faux offline messages
- History
- Screenshots
- Emoticons
- Auto-updates on Windows and Mac, packages on Linux
- And many more options!

[![Build Status](https://travis-ci.org/tux3/qTox.svg)](https://travis-ci.org/tux3/qTox)

==> qtox-1.4.0.tar.gz: qTox-1.4.0/README.md <==
qTox
======

 [**User Manual**](/doc/user_manual_en.md) **⦁**
 [**Compile**](/INSTALL.md) **⦁**
 [**Contribute**](https://github.com/tux3/qTox/wiki#contributing) **⦁**
 [**Report bugs**](https://github.com/tux3/qTox/wiki/Writing-Useful-Bug-Reports) **⦁**
 [**Translate**](https://github.com/tux3/qTox/wiki/Translating) **⦁**
 [**Jenkins builds**](https://build.tox.chat/) **⦁**
 [**Keyboard shortcuts**](https://github.com/tux3/qTox/wiki/Keyboard-shortcuts) **⦁**
 [**Mailing list**](https://lists.tox.chat) **⦁**
 **IRC Channel:** [#qtox@freenode](https://webchat.freenode.net/?channels=qtox)

**qTox is a powerful Tox client that follows the Tox design guidelines while
running on all major platforms.**

----

* **Windows**:
  - [**64 bit installer**](https://build.tox.chat/view/qtox/job/qTox_pkg_windows_x86-64_stable_release/lastSuccessfulBuild/artifact/setup-qtox.exe)
  - [**32 bit installer**](https://build.tox.chat/view/qtox/job/qTox_pkg_windows_x86_stable_release/lastSuccessfulBuild/artifact/setup-qtox.exe)
* **Linux**:
  - [**64 bit download**](https://build.tox.chat/view/Clients/job/qTox_build_linux_x86-64_release/lastSuccessfulBuild/artifact/qTox_build_linux_x86-64_release.tar.xz)
  - [**32 bit download**](https://build.tox.chat/view/Clients/job/qTox_build_linux_x86_release/lastSuccessfulBuild/artifact/qTox_build_linux_x86_release.tar.xz)
  - [**Armhf download**](https://build.tox.chat/job/qTox-qt5.4.2_build_linux_armhf_release/lastSuccessfulBuild/artifact/qTox-qt5.4.2_build_linux_armhf_release.tar.xz)
  - [**packages**](/INSTALL.md#simple-install)
* **Mac**:
  - [**Experimental download**](https://github.com/RowenStipe/qTox-OSX/releases)
* **FreeBSD**:
  - [**Port**](/INSTALL.md#freebsd-easy)
<br/>

Builds other than installer/packages don't receive updates automatically, so
make sure you get back to this site and regularly download the latest version of
qTox.


#### Screenshots
Note: The screenshots may not always be up to date, but they should give a good
idea of the general look and features.


![Screenshot 01](https://i.imgur.com/olb89CN.png)
![Screenshot 02](https://i.imgur.com/tmX8z9s.png)


#### Features

- One to one chat with friends
- Group chats
- File transfers, with previewing of images
- Audio calls, including group calls
- Video calls
- Tox DNS and Tox URI support
- Translations in various languages
- Avatars
- Faux offline messages
- History
- Screenshots
- Emoticons
- Auto-updates on Windows and Mac, packages on Linux
- And many more options!

[![Build Status](https://travis-ci.org/tux3/qTox.svg)](https://travis-ci.org/tux3/qTox)
